@@ -1,7 +1,7 @@
 package Perinci::Examples::ArgsAs;
 
-our $DATE = '2019-07-19'; # DATE
-our $VERSION = '0.818'; # VERSION
+our $DATE = '2019-08-14'; # DATE
+our $VERSION = '0.819'; # VERSION
 
 use 5.010001;
 use strict;
@@ -100,7 +100,7 @@ Perinci::Examples::ArgsAs - Demonstrate various values of `args_as` function met
 
 =head1 VERSION
 
-This document describes version 0.818 of Perinci::Examples::ArgsAs (from Perl distribution Perinci-Examples), released on 2019-07-19.
+This document describes version 0.819 of Perinci::Examples::ArgsAs (from Perl distribution Perinci-Examples), released on 2019-08-14.
 
 =head1 DESCRIPTION
 
@@ -236,7 +236,7 @@ Examples:
 
 =item * With the optional arg3:
 
- args_as_hash(arg1 => "def", arg2 => 20, arg3 => 0.5); # -> ["arg1", "def", "arg2", 20, "arg3", 0.5]
+ args_as_hash(arg1 => "def", arg2 => 20, arg3 => 0.5); # -> ["arg3", 0.5, "arg2", 20, "arg1", "def"]
 
 =back
 
